﻿using System;
using System.Configuration;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.Linq;

namespace GPStoGoogleMap
{
    public partial class TestForm : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));

                //Sets the projection parameters to go from Geodetic (EPSG 4326) or decimal degrees to Google Map projection (Spherical Mercator).
                Proj4Projection proj4 = new Proj4Projection();
                proj4.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326); //Geodetic (decimal degrees).
                proj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();// Google Map projection (Spherical Mercator)

                //Maximum and minimum longitude and latitude values the map to be centered on.
                //Here we are centering on Florida.
                double minx = -88.0656; //Mininum Longitude
                double miny = 24.6526; //Minimum Latitude
                double maxx = -79.0724; //Maximum Longitude
                double maxy = 31.3938; //Maximum Latitude

                //Gets the RectangleShape in the Google Map projection.
                proj4.Open();
                RectangleShape googleMapRectangleShape = proj4.ConvertToExternalProjection(new RectangleShape(minx, maxy, maxx, miny));
                proj4.Close();

                //Sets the extent of the map according to the projected RectangleShape.
                //Notice that a snap to closest zoom level will occur. The map will be centered based on that RectangleShape
                //and it will snap to the closest zoom level to fit the RectangleShape.
                Map1.CurrentExtent = googleMapRectangleShape;
                Map1.MapUnit = GeographyUnit.Meter;

                Map1.MapTools.OverlaySwitcher.Enabled = true;
                Map1.MapTools.MouseCoordinate.Enabled = true;

                //Adds the Google Map as an overlay
                GoogleOverlay google = new GoogleOverlay("Google Map");
                google.JavaScriptLibraryUri = new Uri(ConfigurationManager.AppSettings["GoogleUri"]);
                google.GoogleMapType = GoogleMapType.Normal;
                Map1.CustomOverlays.Add(google);
                this.AddContextMenus();

            }
        }

        private void AddContextMenus()
        {
            ContextMenu mainContextMenu = new ContextMenu("mapContextMenu", 180);

            ContextMenuItem contextMenuView =
                new ContextMenuItem("View");

            ContextMenuItem contextMenuViewNormal =
                new ContextMenuItem("Normal");
            ContextMenuItem contextMenuViewPhysical =
                new ContextMenuItem("Physical");
            ContextMenuItem contextMenuViewSatellite =
                new ContextMenuItem("Satellite");
            ContextMenuItem contextMenuViewHybrid =
                new ContextMenuItem("Hybrid");

            contextMenuViewNormal.Click += new EventHandler<ContextMenuItemClickEventArgs>(this.ContextMenuViewNormal_Click);
            contextMenuViewPhysical.Click += new EventHandler<ContextMenuItemClickEventArgs>(this.ContextMenuViewPhysical_Click);
            contextMenuViewSatellite.Click += new EventHandler<ContextMenuItemClickEventArgs>(this.ContextMenuViewSatellite_Click);
            contextMenuViewHybrid.Click += new EventHandler<ContextMenuItemClickEventArgs>(this.ContextMenuViewHybrid_Click);

            contextMenuView.MenuItems.Add(contextMenuViewNormal);
            contextMenuView.MenuItems.Add(contextMenuViewPhysical);
            contextMenuView.MenuItems.Add(contextMenuViewSatellite);
            contextMenuView.MenuItems.Add(contextMenuViewHybrid);

            mainContextMenu.MenuItems.Add(contextMenuView);

            Map1.ContextMenu = mainContextMenu;
        }

        protected void ContextMenuViewHybrid_Click(object sender, ContextMenuItemClickEventArgs e)
        {
            this.GetGoogleMapOverlay().GoogleMapType = GoogleMapType.Hybrid;
        }

        /// <summary>
        /// Handles the Click event of the ContextMenuViewSatellite control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="ThinkGeo.MapSuite.WebEdition.ContextMenuItemClickEventArgs"/> instance containing the event data.</param>
        protected void ContextMenuViewSatellite_Click(object sender, ContextMenuItemClickEventArgs e)
        {
            this.GetGoogleMapOverlay().GoogleMapType = GoogleMapType.Satellite;
        }

        /// <summary>
        /// Handles the Click event of the ContextMenuViewPhysical control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="ThinkGeo.MapSuite.WebEdition.ContextMenuItemClickEventArgs"/> instance containing the event data.</param>
        protected void ContextMenuViewPhysical_Click(object sender, ContextMenuItemClickEventArgs e)
        {
            this.GetGoogleMapOverlay().GoogleMapType = GoogleMapType.Physical;
        }

        /// <summary>
        /// Handles the Click event of the ContextMenuViewNormal control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="ThinkGeo.MapSuite.WebEdition.ContextMenuItemClickEventArgs"/> instance containing the event data.</param>
        protected void ContextMenuViewNormal_Click(object sender, ContextMenuItemClickEventArgs e)
        {
            this.GetGoogleMapOverlay().GoogleMapType = GoogleMapType.Normal;
        }

        /// <summary>
        /// Gets the google map overlay.
        /// </summary>
        /// <returns></returns>
        private GoogleOverlay GetGoogleMapOverlay()
        {
            GoogleOverlay googleOverLay =
                (GoogleOverlay)this.Map1.CustomOverlays.Single(o => o.Name.Contains("Google Map"));
            return googleOverLay;
        }

    }
}
